"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _reactTestRenderer = _interopRequireDefault(require("react-test-renderer"));

var _StaticRouter = _interopRequireDefault(require("react-router-dom/StaticRouter"));

var _Link = _interopRequireDefault(require("./Link"));

var render = function render(props) {
  var wrapped = _react.default.createElement(_StaticRouter.default, {
    location: new URL('http://example.com'),
    context: {}
  }, _react.default.createElement(_Link.default, props));

  return {
    json: _reactTestRenderer.default.create(wrapped).toJSON(),
    // for snapshots
    shallow: (0, _enzyme.shallow)(wrapped) // for enzyme shallow render inspection

  };
};

describe('Server rendering', function () {
  var internalToString = '/foo/bar';
  var internalToLoc = {
    pathname: '/foo/bar'
  };
  var externalToString = 'http://example.com/foo/bar';
  var externalToUrl = new URL('http://example.com/foo/bar');
  it('Renders a react-router <Link> for internal route string', function () {
    var rendered = render({
      to: internalToString
    });
    var link = rendered.shallow.find('Link');
    expect(link.exists()).toBe(true);
    expect(link.props().to).toBe(internalToString);
  });
  it('Renders a react-router <Link> for internal route object', function () {
    var rendered = render({
      to: internalToLoc
    });
    var link = rendered.shallow.find('Link');
    expect(link.exists()).toBe(true);
    expect(link.props().to).toBe(internalToLoc);
  });
  it('Renders a valid link for external URL string', function () {
    expect(render({
      to: externalToString
    }).json).toMatchSnapshot();
  });
  it('Renders a valid link for external URL object', function () {
    expect(render({
      to: externalToUrl
    }).json).toMatchSnapshot();
  });
});
//# sourceMappingURL=link.test.js.map