"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _server = _interopRequireDefault(require("react-dom/server"));

var _StaticRouter = _interopRequireDefault(require("react-router-dom/StaticRouter"));

var _Redirect = _interopRequireWildcard(require("./Redirect"));

var renderToContext = function renderToContext(to, permanent) {
  var context = {};

  _server.default.renderToString(_react.default.createElement(_StaticRouter.default, {
    location: new URL('http://example.com'),
    context: context
  }, _react.default.createElement(_Redirect.default, {
    to: to,
    permanent: permanent
  })));

  return context;
};

describe('Server rendering', function () {
  it('sets React Router context for "local" redirect, nothing from Redirect.rewind()', function () {
    var internalTo = 'foo/bar';
    var httpContext = renderToContext(internalTo);
    expect(httpContext).toMatchObject({
      url: internalTo
    });
    expect(httpContext.permanent).toBeUndefined();
    expect(_Redirect.default.rewind()).toBeUndefined();
  });
  it('provides external redirect URL from Redirect.rewind(), nothing from React Router context', function () {
    var externalTo = 'http://foo.com'; // non-SSL

    var httpContext = renderToContext(externalTo);
    expect(httpContext.url).toBeUndefined();

    var externalRedirect = _Redirect.default.rewind();

    expect(externalRedirect).toMatchObject({
      url: externalTo
    });
    expect(externalRedirect.permanent).toBeUndefined();
    externalTo = 'https://foo.com'; // SSL

    var httpsContext = renderToContext(externalTo);
    expect(httpsContext.url).toBeUndefined();
    expect(_Redirect.default.rewind()).toMatchObject({
      url: externalTo
    });
  });
  it('handles location object "to" props', function () {
    var externalTo = new URL('https://foo.com/foo');
    var httpsContext = renderToContext(externalTo);
    expect(httpsContext.url).toBeUndefined();

    var externalRedirect = _Redirect.default.rewind();

    expect(externalRedirect).toMatchObject({
      url: externalTo.href
    });
    expect(externalRedirect.permanent).toBeUndefined();
    var internalTo = {
      pathname: '/foo/bar',
      search: '?foo=bar'
    };
    var httpContext = renderToContext(internalTo);
    expect(httpContext).toMatchObject({
      url: "".concat(internalTo.pathname).concat(internalTo.search)
    });
    expect(httpContext.permanent).toBeUndefined();
    expect(_Redirect.default.rewind()).toBeUndefined();
  });
  it('sets `permanent` on internal permanent redirect', function () {
    var internalTo = 'foo/bar';
    var permanent = true;
    var httpContext = renderToContext(internalTo, permanent);
    expect(httpContext).toMatchObject({
      url: internalTo,
      permanent: permanent
    });
  });
  it('sets `permanent` on external permanent redirect', function () {
    var externalTo = 'https://foo.com'; // SSL

    var permanent = true;
    var httpsContext = renderToContext(externalTo, permanent);
    expect(httpsContext.url).toBeUndefined();
    expect(_Redirect.default.rewind()).toMatchObject({
      url: externalTo,
      permanent: permanent
    });
  });
  it('returns undefined when no Redirect', function () {
    _server.default.renderToString(_react.default.createElement("div", null));

    expect(_Redirect.default.rewind()).toBeUndefined();
  });
});
describe('Client behavior', function () {
  global.window = {
    location: {
      replace: jest.fn()
    }
  };
  it('calls window.location.replace for external URLs', function () {
    window.location.replace.mockClear();
    var url = 'https://google.com';
    (0, _Redirect.handleStateChangeOnClient)({
      url: url
    });
    expect(window.location.replace).toHaveBeenCalledWith(url);
  });
  it('does not call window.location.replace for internal URLs', function () {
    window.location.replace.mockClear();
    var url = '/foo/bar';
    (0, _Redirect.handleStateChangeOnClient)({
      url: url
    });
    expect(window.location.replace).not.toHaveBeenCalled();
  });
});
//# sourceMappingURL=redirect.test.js.map