"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFindMatches = exports.getMatchedChildRoutes = void 0;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _matchPath = _interopRequireDefault(require("react-router-dom/matchPath"));

// munge a route's 'relative' `path` with the full matchedPath
var _routeMatchOptions = function _routeMatchOptions(route, matchedPath) {
  return {
    path: "".concat(matchedPath).concat(route.path || '').replace('//', '/'),
    strict: route.strict,
    exact: route.exact
  };
};
/*
 * Determine whether the indexRoute or nested route should be considered the
 * child route for a particular MatchedRoute
 */


var getMatchedChildRoutes = function getMatchedChildRoutes(matchedRoute) {
  var route = matchedRoute.route,
      match = matchedRoute.match;

  if (match.isExact) {
    return route.indexRoute ? [route.indexRoute] : [];
  }

  return route.routes || [];
};
/*
 * Find all routes in the routes array that match the provided URL, including
 * nested routes that may have async components
 */


exports.getMatchedChildRoutes = getMatchedChildRoutes;

var _getFindMatchesPath = function _getFindMatchesPath() {
  var routes = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  return function () {
    var path = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    var matchedRoutes = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
    var matchedPath = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';
    var route = routes.find(function (r) {
      return (0, _matchPath.default)(path, _routeMatchOptions(r, matchedPath));
    }); // take the first match

    if (!route) {
      return matchedRoutes;
    } // add the route and its `match` object to the array of matched routes


    var currentMatchOptions = _routeMatchOptions(route, matchedPath);

    var match = (0, _matchPath.default)(path, currentMatchOptions);

    if (!match) {
      // we know that this won't ever run because we've established the match in
      // `.find`, but this check is for type safety
      return matchedRoutes;
    }

    var matchedRoute = {
      route: route,
      match: match
    };
    var currentMatchedRoutes = [].concat((0, _toConsumableArray2.default)(matchedRoutes), [matchedRoute]); // recurse using child route(s)

    return _getFindMatchesPath(getMatchedChildRoutes(matchedRoute))(path, currentMatchedRoutes, currentMatchOptions.path);
  };
};
/*
 * A curried interface into `_getFindMatchesPath`, using `basename`
 * + `location` instead of `path`
 */


var getFindMatches = function getFindMatches(routes, basename) {
  var findMatches = _getFindMatchesPath(routes);

  return function (location) {
    return findMatches(location.pathname.replace(basename, ''));
  };
};

exports.getFindMatches = getFindMatches;
//# sourceMappingURL=matcher.js.map