"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _matcher = require("./matcher");

describe('getMatchedChildRoutes', function () {
  it('returns [route.indexRoute] for exact match', function () {
    var matchedRoute = {
      route: {
        indexRoute: 'foo'
      },
      match: {
        isExact: true
      }
    };
    var childRoutes = (0, _matcher.getMatchedChildRoutes)(matchedRoute);
    expect(childRoutes).toEqual([matchedRoute.route.indexRoute]);
  });
  it('returns route.routes for not-exact match', function () {
    var matchedRoute = {
      route: {
        indexRoute: 'foo',
        routes: ['bar', 'baz']
      },
      match: {
        isExact: false
      }
    };
    var childRoutes = (0, _matcher.getMatchedChildRoutes)(matchedRoute);
    expect(childRoutes).toEqual(matchedRoute.route.routes);
  });
  it('returns empty array for exact match without index route', function () {
    var matchedRoute = {
      route: {
        routes: ['bar', 'baz']
      },
      match: {
        isExact: true
      }
    };
    var childRoutes = (0, _matcher.getMatchedChildRoutes)(matchedRoute);
    expect(childRoutes).toEqual([]);
  });
  it('returns empty array for not-exact match without route.routes', function () {
    var matchedRoute = {
      route: {
        indexRoute: 'foo'
      },
      match: {
        isExact: false
      }
    };
    var childRoutes = (0, _matcher.getMatchedChildRoutes)(matchedRoute);
    expect(childRoutes).toEqual([]);
  });
});
describe('getFindMatches', function () {
  var Component = function Component() {
    return _react.default.createElement("div", null);
  };

  var bar = {
    path: '/bar',
    getComponent: function getComponent() {
      return Promise.resolve(Component);
    }
  };
  var foo = {
    path: '/foo',
    getComponent: function getComponent() {
      return Promise.resolve(Component);
    },
    routes: [bar]
  };
  var qux = {
    path: '/qux',
    getComponent: function getComponent() {
      return Promise.resolve(Component);
    }
  };
  var baz = {
    path: '/baz',
    component: Component,
    routes: [qux]
  };
  var root = {
    path: '/',
    getComponent: function getComponent() {
      return Promise.resolve(Component);
    },
    routes: [foo, baz]
  };
  var findMatches = (0, _matcher.getFindMatches)([root]);
  it('returns all matched synchronous routes', function () {
    var location = new URL('http://example.com/foo/bar');
    expect(findMatches(location).map(function (_ref) {
      var route = _ref.route;
      return route;
    })).toEqual([root, foo, bar]);
  });
  it('returns all matched asynchronous routes', function () {
    var location = new URL('http://example.com/baz/qux');
    expect(findMatches(location).map(function (_ref2) {
      var route = _ref2.route;
      return route;
    })).toEqual([root, baz, qux]);
  });
});
//# sourceMappingURL=matcher.test.js.map