"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getMatchedQueries = exports.decodeParams = void 0;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var decodeParams = function decodeParams(params) {
  return Object.keys(params).reduce(function (decodedParams, key) {
    if (typeof params[key] !== 'undefined') {
      // skip 'undefined' values that cannot be encoded (null is okay)
      decodedParams[key] = params[key] && decodeURI(params[key]);
    }

    return decodedParams;
  }, {});
};
/*
 * find all routes from a given array of route config objects that match the
 * supplied `location`
 *
 * this function matches the signature of `react-router-config`'s `_resolveRouteMatches`
 * function, but interprets all `route.path` settings as nested
 *
 * @see {@link https://github.com/ReactTraining/react-router/tree/master/packages/react-router-config#matchroutesroutes-pathname}
 */

/*
 * Collect the return values of each query functions associated with the matched
 * routes, called with the provided location URL
 *
 * The function returned from calling `_matchedRouteQueriesReducer` with a
 * `location` should be used as the callback to an `array.reduce` call.
 */


exports.decodeParams = decodeParams;

var _matchedRouteQueriesReducer = function _matchedRouteQueriesReducer(location, state) {
  return function (queries, _ref) {
    var route = _ref.route,
        match = _ref.match;

    if (!route.query) {
      return queries;
    }

    var routeQueryFns = route.query instanceof Array ? route.query : [route.query]; // call the query functions with non-url-encoded params

    var params = decodeParams(match.params);
    var routeQueries = routeQueryFns.map(function (queryFn) {
      return queryFn((0, _objectSpread2.default)({}, match, {
        location: location,
        params: params
      }), state);
    }).filter(function (query) {
      return query;
    });
    return [].concat((0, _toConsumableArray2.default)(queries), (0, _toConsumableArray2.default)(routeQueries));
  };
};
/*
 * A synchronous, curried interface to derive the query values returned by the
 * query functions of a provided set of routes given a particular location
 */


var getMatchedQueries = function getMatchedQueries(location, state) {
  return function (matchedRoutes) {
    return matchedRoutes.reduce(_matchedRouteQueriesReducer(location, state), []);
  };
};

exports.getMatchedQueries = getMatchedQueries;
//# sourceMappingURL=query.js.map