"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _objectSpread3 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _query = require("./query");

describe('decodeParams', function () {
  it('url-decodes all defined values of object', function () {
    var rawValues = ['&asdfkj%20sfd', 'asdfs', '%dsjdasdf///', '驚くばかり'];
    var encodedValues = rawValues.map(encodeURI);
    var params = encodedValues.reduce(function (params, v, k) {
      return (0, _objectSpread3.default)({}, params, (0, _defineProperty2.default)({}, k, v));
    }, {});
    var decoded = (0, _query.decodeParams)(params);
    expect(Object.keys(decoded)).toEqual(Object.keys(params));
    Object.keys(decoded).forEach(function (k) {
      expect(decoded[k]).toEqual(rawValues[k]);
    });
  });
  it('skips keys with undefined values', function () {
    var params = {
      foo: undefined,
      bar: 'baz',
      qux: null
    };
    var decoded = (0, _query.decodeParams)(params);
    expect(decoded).toEqual({
      bar: 'baz',
      qux: null
    });
  });
  it('returns empty object unchanged', function () {
    var object = {};
    var decoded = (0, _query.decodeParams)(object);
    expect(decoded).toEqual(object);
  });
});
describe('getMatchedQueries', function () {
  it('returns queries derived from the query function in matched route', function () {
    var location = new URL('http://foo.com/bar/baz');
    var matchedRoute = {
      route: {
        path: '/',
        query: jest.fn(function () {
          return 'bar';
        })
      },
      match: {
        params: {}
      }
    };
    var queries = (0, _query.getMatchedQueries)(location)([matchedRoute]);
    expect(queries).toEqual(['bar']);
  });
  it('returns empty array when no query functions in matchedRoute', function () {
    var location = new URL('http://foo.com/bar/baz');
    var params = {
      foo: 'bar'
    };
    var matchedRoute = {
      route: {
        path: '/'
      },
      match: {
        params: params
      }
    };
    var queries = (0, _query.getMatchedQueries)(location)([matchedRoute]);
    expect(queries).toEqual([]);
  });
  it('calls query functions with params + location object', function () {
    var state = {};
    var location = new URL('http://foo.com/bar/baz');
    var path = '/';
    var match = {
      isExact: false,
      params: {
        foo: 'bar'
      },
      path: path,
      url: '/'
    };
    var matchedRoute = {
      route: {
        path: path,
        query: jest.fn()
      },
      match: match
    };
    (0, _query.getMatchedQueries)(location, state)([matchedRoute]);
    expect(matchedRoute.route.query).toHaveBeenCalledWith((0, _objectSpread3.default)({}, match, {
      location: location
    }), state);
  });
});
//# sourceMappingURL=query.test.js.map